@@ -1,28 +1,22 @@
+use 5.006;
+use strict;
+use warnings;
+
 package Object::Tiny::Lvalue;
-BEGIN {
-  $Object::Tiny::Lvalue::VERSION = '1.07';
-}
-
+$Object::Tiny::Lvalue::VERSION = '1.08';
 # ABSTRACT: minimal class builder with lvalue accessors
 
-use strict 'vars';
-
-BEGIN {
-	require 5.003_96;
-}
-
 sub import {
 	return unless shift eq __PACKAGE__;
 	my $pkg = caller;
-	my $child = 0+@{"${pkg}::ISA"};
-	eval join "\n",
+	eval join "\n", (
 		"package $pkg;",
-		($child ? () : "\@${pkg}::ISA = 'Object::Tiny::Lvalue';"),
+		'our @ISA = "Object::Tiny::Lvalue" unless @ISA;',
 		map {
-			defined and ! ref and /^[^\W\d]\w*$/s
-				or die "Invalid accessor name '$_'";
-			"sub $_ : lvalue { \$_[0]->{$_} }"
-		} @_;
+			defined and /\A[^\W\d]\w*\z/ or die "Invalid accessor name '$_'";
+			"sub $_ : lvalue { \$_[0]->{$_} }";
+		} @_
+	);
 	die "Failed to generate $pkg" if $@;
 	return 1;
 }
@@ -34,17 +28,19 @@ sub new {
 
 1;
 
-
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Object::Tiny::Lvalue - minimal class builder with lvalue accessors
 
 =head1 VERSION
 
-version 1.07
+version 1.08
 
 =head1 SYNOPSIS
 
@@ -67,17 +63,13 @@ This is a clone of L<Object::Tiny|Object::Tiny>, but adjusted to create accessor
 
 =head1 AUTHOR
 
-  Aristotle Pagaltzis <pagaltzis@gmx.de>
+Aristotle Pagaltzis <pagaltzis@gmx.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Aristotle Pagaltzis.
+This software is copyright (c) 2015 by Aristotle Pagaltzis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
